/*******************************************************************************
* File Name: SEL3.h  
* Version 2.20
*
* Description:
*  This file contains Pin function prototypes and register defines
*
* Note:
*
********************************************************************************
* Copyright 2008-2015, Cypress Semiconductor Corporation.  All rights reserved.
* You may use this file only in accordance with the license, terms, conditions, 
* disclaimers, and limitations in the end user license agreement accompanying 
* the software package with which this file was provided.
*******************************************************************************/

#if !defined(CY_PINS_SEL3_H) /* Pins SEL3_H */
#define CY_PINS_SEL3_H

#include "cytypes.h"
#include "cyfitter.h"
#include "cypins.h"
#include "SEL3_aliases.h"

/* APIs are not generated for P15[7:6] */
#if !(CY_PSOC5A &&\
	 SEL3__PORT == 15 && ((SEL3__MASK & 0xC0) != 0))


/***************************************
*        Function Prototypes             
***************************************/    

/**
* \addtogroup group_general
* @{
*/
void    SEL3_Write(uint8 value);
void    SEL3_SetDriveMode(uint8 mode);
uint8   SEL3_ReadDataReg(void);
uint8   SEL3_Read(void);
void    SEL3_SetInterruptMode(uint16 position, uint16 mode);
uint8   SEL3_ClearInterrupt(void);
/** @} general */

/***************************************
*           API Constants        
***************************************/
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup driveMode Drive mode constants
     * \brief Constants to be passed as "mode" parameter in the SEL3_SetDriveMode() function.
     *  @{
     */
        #define SEL3_DM_ALG_HIZ         PIN_DM_ALG_HIZ
        #define SEL3_DM_DIG_HIZ         PIN_DM_DIG_HIZ
        #define SEL3_DM_RES_UP          PIN_DM_RES_UP
        #define SEL3_DM_RES_DWN         PIN_DM_RES_DWN
        #define SEL3_DM_OD_LO           PIN_DM_OD_LO
        #define SEL3_DM_OD_HI           PIN_DM_OD_HI
        #define SEL3_DM_STRONG          PIN_DM_STRONG
        #define SEL3_DM_RES_UPDWN       PIN_DM_RES_UPDWN
    /** @} driveMode */
/** @} group_constants */
    
/* Digital Port Constants */
#define SEL3_MASK               SEL3__MASK
#define SEL3_SHIFT              SEL3__SHIFT
#define SEL3_WIDTH              3u

/* Interrupt constants */
#if defined(SEL3__INTSTAT)
/**
* \addtogroup group_constants
* @{
*/
    /** \addtogroup intrMode Interrupt constants
     * \brief Constants to be passed as "mode" parameter in SEL3_SetInterruptMode() function.
     *  @{
     */
        #define SEL3_INTR_NONE      (uint16)(0x0000u)
        #define SEL3_INTR_RISING    (uint16)(0x0001u)
        #define SEL3_INTR_FALLING   (uint16)(0x0002u)
        #define SEL3_INTR_BOTH      (uint16)(0x0003u) 
    /** @} intrMode */
/** @} group_constants */

    #define SEL3_INTR_MASK      (0x01u) 
#endif /* (SEL3__INTSTAT) */


/***************************************
*             Registers        
***************************************/

/* Main Port Registers */
/* Pin State */
#define SEL3_PS                     (* (reg8 *) SEL3__PS)
/* Data Register */
#define SEL3_DR                     (* (reg8 *) SEL3__DR)
/* Port Number */
#define SEL3_PRT_NUM                (* (reg8 *) SEL3__PRT) 
/* Connect to Analog Globals */                                                  
#define SEL3_AG                     (* (reg8 *) SEL3__AG)                       
/* Analog MUX bux enable */
#define SEL3_AMUX                   (* (reg8 *) SEL3__AMUX) 
/* Bidirectional Enable */                                                        
#define SEL3_BIE                    (* (reg8 *) SEL3__BIE)
/* Bit-mask for Aliased Register Access */
#define SEL3_BIT_MASK               (* (reg8 *) SEL3__BIT_MASK)
/* Bypass Enable */
#define SEL3_BYP                    (* (reg8 *) SEL3__BYP)
/* Port wide control signals */                                                   
#define SEL3_CTL                    (* (reg8 *) SEL3__CTL)
/* Drive Modes */
#define SEL3_DM0                    (* (reg8 *) SEL3__DM0) 
#define SEL3_DM1                    (* (reg8 *) SEL3__DM1)
#define SEL3_DM2                    (* (reg8 *) SEL3__DM2) 
/* Input Buffer Disable Override */
#define SEL3_INP_DIS                (* (reg8 *) SEL3__INP_DIS)
/* LCD Common or Segment Drive */
#define SEL3_LCD_COM_SEG            (* (reg8 *) SEL3__LCD_COM_SEG)
/* Enable Segment LCD */
#define SEL3_LCD_EN                 (* (reg8 *) SEL3__LCD_EN)
/* Slew Rate Control */
#define SEL3_SLW                    (* (reg8 *) SEL3__SLW)

/* DSI Port Registers */
/* Global DSI Select Register */
#define SEL3_PRTDSI__CAPS_SEL       (* (reg8 *) SEL3__PRTDSI__CAPS_SEL) 
/* Double Sync Enable */
#define SEL3_PRTDSI__DBL_SYNC_IN    (* (reg8 *) SEL3__PRTDSI__DBL_SYNC_IN) 
/* Output Enable Select Drive Strength */
#define SEL3_PRTDSI__OE_SEL0        (* (reg8 *) SEL3__PRTDSI__OE_SEL0) 
#define SEL3_PRTDSI__OE_SEL1        (* (reg8 *) SEL3__PRTDSI__OE_SEL1) 
/* Port Pin Output Select Registers */
#define SEL3_PRTDSI__OUT_SEL0       (* (reg8 *) SEL3__PRTDSI__OUT_SEL0) 
#define SEL3_PRTDSI__OUT_SEL1       (* (reg8 *) SEL3__PRTDSI__OUT_SEL1) 
/* Sync Output Enable Registers */
#define SEL3_PRTDSI__SYNC_OUT       (* (reg8 *) SEL3__PRTDSI__SYNC_OUT) 

/* SIO registers */
#if defined(SEL3__SIO_CFG)
    #define SEL3_SIO_HYST_EN        (* (reg8 *) SEL3__SIO_HYST_EN)
    #define SEL3_SIO_REG_HIFREQ     (* (reg8 *) SEL3__SIO_REG_HIFREQ)
    #define SEL3_SIO_CFG            (* (reg8 *) SEL3__SIO_CFG)
    #define SEL3_SIO_DIFF           (* (reg8 *) SEL3__SIO_DIFF)
#endif /* (SEL3__SIO_CFG) */

/* Interrupt Registers */
#if defined(SEL3__INTSTAT)
    #define SEL3_INTSTAT            (* (reg8 *) SEL3__INTSTAT)
    #define SEL3_SNAP               (* (reg8 *) SEL3__SNAP)
    
	#define SEL3_0_INTTYPE_REG 		(* (reg8 *) SEL3__0__INTTYPE)
	#define SEL3_1_INTTYPE_REG 		(* (reg8 *) SEL3__1__INTTYPE)
	#define SEL3_2_INTTYPE_REG 		(* (reg8 *) SEL3__2__INTTYPE)
#endif /* (SEL3__INTSTAT) */

#endif /* CY_PSOC5A... */

#endif /*  CY_PINS_SEL3_H */


/* [] END OF FILE */
